.split-left-template-selector[data-v-246aa2a7]{padding-right:10px;background-color:#f8f8f9}.split-left-template-selector .ivu-form-item[data-v-246aa2a7]{margin-bottom:0;padding-bottom:5px}.flex_input{position:absolute}.split-left-form{height:calc(100vh - 89px);overflow-y:auto;overflow-x:auto;border-bottom:1px solid #dcdee2;padding-right:10px;white-space:nowrap}.split-left-form .ivu-form-item{margin-bottom:12px}.split-right-bar[data-v-896f5b78]{height:28px;overflow-x:auto;overflow-y:hidden;white-space:nowrap;border-bottom:1px solid #dcdee2}.device-btn-group[data-v-896f5b78]{margin:2px 2px}.device-btn[data-v-896f5b78]{border:1px solid #c3d9ee;border-radius:3px 0 0 3px;background:#fff;cursor:pointer;padding:2px 5px}.screenshot-btn[data-v-896f5b78]{border:1px solid #c3d9ee;border-left:0;border-radius:0 3px 3px 0;background:#fff;cursor:pointer;padding:2px 5px}.contextmenu-item{display:-webkit-box;display:-ms-flexbox;display:flex;min-height:40px;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.contextmenu-item-container{display:block}.title[data-v-09affdc8]{font-size:14px}.info[data-v-09affdc8]{color:#696969;font-size:12px}.tag[data-v-09affdc8]{color:green}.property_font[data-v-09affdc8]{font-size:12px;font-weight:700;color:#aeaeae;padding-left:5px;padding-right:5px}.description[data-v-14c96c95]{white-space:nowrap;overflow:hidden;text-overflow:ellipsis}.page{text-align:center;margin-top:5px}.event-table .ivu-table-cell{padding-left:3px;padding-right:3px}.row-contextmenu{position:absolute}.split-right-table[data-v-7b55e704]{height:calc(100vh - 28px);overflow-y:auto;border-bottom:1px solid #dcdee2}.demo-split[data-v-7b55e704]{height:200px;border:1px solid #dcdee2}.demo-split-pane[data-v-7b55e704]{padding:10px;overflow-y:auto;height:100%}.bugit-split[data-v-440bea07]{height:100vh}#app{font-family:Avenir,Helvetica,Arial,sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;color:#2c3e50}